@@ -1,27 +1,21 @@
 /*
- *   Copyright 2013 Martin Gräßlin <mgraesslin@kde.org>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Lesser General Public
- *   License as published by the Free Software Foundation; either
- *   version 2.1 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public
- *   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2013 Martin Gräßlin <mgraesslin@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
+
+#include <QSignalSpy>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
+#include <QX11Info>
+#endif
+
+#include <kmanagerselection.h>
 #include <kwindoweffects.h>
 #include <kwindowsystem.h>
-#include <kmanagerselection.h>
 #include <netwm.h>
-#include <QSignalSpy>
 #include <qtest_widgets.h>
-#include <QX11Info>
 #include <xcb/xcb.h>
 
 Q_DECLARE_METATYPE(KWindowEffects::SlideFromLocation)
@@ -35,9 +29,7 @@ private Q_SLOTS:
     void testSlideWindow_data();
     void testSlideWindow();
     void testSlideWindowRemove();
-    void testSlideWindowWidget_data();
-    void testSlideWindowWidget();
-    void testSlideWindowWidgetRemove();
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
     void testPresentWindows_data();
     void testPresentWindows();
     void testPresentWindowsEmptyGroup();
@@ -46,10 +38,13 @@ private Q_SLOTS:
     void testHighlightWindows_data();
     void testHighlightWindows();
     void testHighlightWindowsEmpty();
+#endif
     void testBlur_data();
     void testBlur();
     void testBlurDisable();
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 67)
     void testMarkAsDashboard();
+#endif
     void testEffectAvailable_data();
     void testEffectAvailable();
 
@@ -61,9 +56,11 @@ private:
     void performAtomIsRemoveTest(xcb_window_t window, xcb_atom_t atom);
     void getHelperAtom(const QByteArray &name, xcb_atom_t *atom) const;
     xcb_atom_t m_slide;
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
     xcb_atom_t m_presentWindows;
     xcb_atom_t m_presentWindowsGroup;
     xcb_atom_t m_highlightWindows;
+#endif
     xcb_atom_t m_thumbnails;
     xcb_atom_t m_blur;
     QScopedPointer<QWindow> m_window;
@@ -79,9 +76,11 @@ void KWindowEffectsTest::initTestCase()
     QVERIFY(m_widget->effectiveWinId() != XCB_WINDOW_NONE);
 
     getHelperAtom(QByteArrayLiteral("_KDE_SLIDE"), &m_slide);
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
     getHelperAtom(QByteArrayLiteral("_KDE_PRESENT_WINDOWS_DESKTOP"), &m_presentWindows);
     getHelperAtom(QByteArrayLiteral("_KDE_PRESENT_WINDOWS_GROUP"), &m_presentWindowsGroup);
     getHelperAtom(QByteArrayLiteral("_KDE_WINDOW_HIGHLIGHT"), &m_highlightWindows);
+#endif
     getHelperAtom(QByteArrayLiteral("_KDE_WINDOW_PREVIEW"), &m_thumbnails);
     getHelperAtom(QByteArrayLiteral("_KDE_NET_WM_BLUR_BEHIND_REGION"), &m_blur);
 }
@@ -101,9 +100,9 @@ void KWindowEffectsTest::testSlideWindow_data()
     QTest::addColumn<int>("offset");
     QTest::addColumn<KWindowEffects::SlideFromLocation>("location");
 
-    QTest::newRow("Left")   << 10 << KWindowEffects::LeftEdge;
-    QTest::newRow("Right")  << 20 << KWindowEffects::RightEdge;
-    QTest::newRow("Top")    <<  0 << KWindowEffects::TopEdge;
+    QTest::newRow("Left") << 10 << KWindowEffects::LeftEdge;
+    QTest::newRow("Right") << 20 << KWindowEffects::RightEdge;
+    QTest::newRow("Top") << 0 << KWindowEffects::TopEdge;
     QTest::newRow("Bottom") << -1 << KWindowEffects::BottomEdge;
 }
 
@@ -112,7 +111,7 @@ void KWindowEffectsTest::testSlideWindow()
     QFETCH(int, offset);
     QFETCH(KWindowEffects::SlideFromLocation, location);
 
-    KWindowEffects::slideWindow(m_window->winId(), location, offset);
+    KWindowEffects::slideWindow(m_window.data(), location, offset);
     performSlideWindowTest(m_window->winId(), offset, location);
 }
 
@@ -120,41 +119,11 @@ void KWindowEffectsTest::testSlideWindowRemove()
 {
     xcb_window_t window = m_window->winId();
     // first install the atom
-    KWindowEffects::slideWindow(window, KWindowEffects::TopEdge, 0);
+    KWindowEffects::slideWindow(m_window.data(), KWindowEffects::TopEdge, 0);
     performSlideWindowTest(window, 0, KWindowEffects::TopEdge);
 
     // now delete it
-    KWindowEffects::slideWindow(window, KWindowEffects::NoEdge, 0);
-    performSlideWindowRemoveTest(window);
-}
-
-void KWindowEffectsTest::testSlideWindowWidget_data()
-{
-    QTest::addColumn<KWindowEffects::SlideFromLocation>("location");
-
-    QTest::newRow("Left")   << KWindowEffects::LeftEdge;
-    QTest::newRow("Right")  << KWindowEffects::RightEdge;
-    QTest::newRow("Top")    << KWindowEffects::TopEdge;
-    QTest::newRow("Bottom") << KWindowEffects::BottomEdge;
-}
-
-void KWindowEffectsTest::testSlideWindowWidget()
-{
-    QFETCH(KWindowEffects::SlideFromLocation, location);
-
-    KWindowEffects::slideWindow(m_widget->effectiveWinId(), location);
-    performSlideWindowTest(m_widget->effectiveWinId(), -1, location);
-}
-
-void KWindowEffectsTest::testSlideWindowWidgetRemove()
-{
-    xcb_window_t window = m_widget->effectiveWinId();
-    // first install the atom
-    KWindowEffects::slideWindow(m_widget->effectiveWinId(), KWindowEffects::TopEdge);
-    performSlideWindowTest(window, -1, KWindowEffects::TopEdge);
-
-    // now delete it
-    KWindowEffects::slideWindow(m_widget->effectiveWinId(), KWindowEffects::NoEdge);
+    KWindowEffects::slideWindow(m_window.data(), KWindowEffects::NoEdge, 0);
     performSlideWindowRemoveTest(window);
 }
 
@@ -202,6 +171,7 @@ int32_t KWindowEffectsTest::locationToValue(KWindowEffects::SlideFromLocation lo
     }
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
 void KWindowEffectsTest::testPresentWindows_data()
 {
     QTest::addColumn<int>("desktop");
@@ -212,7 +182,9 @@ void KWindowEffectsTest::testPresentWindows_data()
     QTest::newRow("3") << 3;
     QTest::newRow("4") << 4;
 }
+#endif
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
 void KWindowEffectsTest::testPresentWindows()
 {
     QFETCH(int, desktop);
@@ -220,8 +192,7 @@ void KWindowEffectsTest::testPresentWindows()
     KWindowEffects::presentWindows(m_window->winId(), desktop);
 
     xcb_connection_t *c = QX11Info::connection();
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(),
-                                       m_presentWindows, m_presentWindows, 0, 100);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(), m_presentWindows, m_presentWindows, 0, 100);
     QScopedPointer<xcb_get_property_reply_t, QScopedPointerPodDeleter> reply(xcb_get_property_reply(c, cookie, nullptr));
     QVERIFY(!reply.isNull());
     QCOMPARE(reply->format, uint8_t(32));
@@ -230,49 +201,60 @@ void KWindowEffectsTest::testPresentWindows()
     int32_t *data = static_cast<int32_t *>(xcb_get_property_value(reply.data()));
     QCOMPARE(data[0], desktop);
 }
+#endif
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
 void KWindowEffectsTest::testPresentWindowsEmptyGroup()
 {
     KWindowEffects::presentWindows(m_window->winId(), QList<WId>());
 
     xcb_connection_t *c = QX11Info::connection();
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(),
-                                       m_presentWindowsGroup, m_presentWindowsGroup, 0, 100);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(), m_presentWindowsGroup, m_presentWindowsGroup, 0, 100);
     QScopedPointer<xcb_get_property_reply_t, QScopedPointerPodDeleter> reply(xcb_get_property_reply(c, cookie, nullptr));
     QVERIFY(!reply.isNull());
     QCOMPARE(reply->type, xcb_atom_t(XCB_ATOM_NONE));
 }
+#endif
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
 void KWindowEffectsTest::testPresentWindowsGroup_data()
 {
-    QTest::addColumn<QList<WId> >("windows");
+    QTest::addColumn<QList<WId>>("windows");
 
     QTest::newRow("one") << (QList<WId>() << m_window->winId());
     QTest::newRow("two") << (QList<WId>() << m_window->winId() << m_widget->effectiveWinId());
 }
+#endif
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
 void KWindowEffectsTest::testPresentWindowsGroup()
 {
     QFETCH(QList<WId>, windows);
     KWindowEffects::presentWindows(m_window->winId(), windows);
     performWindowsOnPropertyTest(m_presentWindowsGroup, windows);
 }
+#endif
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
 void KWindowEffectsTest::testHighlightWindows_data()
 {
-    QTest::addColumn<QList<WId> >("windows");
+    QTest::addColumn<QList<WId>>("windows");
 
     QTest::newRow("one") << (QList<WId>() << m_window->winId());
     QTest::newRow("two") << (QList<WId>() << m_window->winId() << m_widget->effectiveWinId());
 }
+#endif
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
 void KWindowEffectsTest::testHighlightWindows()
 {
     QFETCH(QList<WId>, windows);
     KWindowEffects::highlightWindows(m_window->winId(), windows);
     performWindowsOnPropertyTest(m_highlightWindows, windows);
 }
+#endif
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
 void KWindowEffectsTest::testHighlightWindowsEmpty()
 {
     // ensure it's empty
@@ -290,12 +272,12 @@ void KWindowEffectsTest::testHighlightWindowsEmpty()
     KWindowEffects::highlightWindows(m_window->winId(), QList<WId>());
     performAtomIsRemoveTest(m_window->winId(), m_highlightWindows);
 }
+#endif
 
-void KWindowEffectsTest::performWindowsOnPropertyTest(xcb_atom_t atom, const QList< WId > &windows)
+void KWindowEffectsTest::performWindowsOnPropertyTest(xcb_atom_t atom, const QList<WId> &windows)
 {
     xcb_connection_t *c = QX11Info::connection();
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(),
-                                       atom, atom, 0, 100);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(), atom, atom, 0, 100);
     QScopedPointer<xcb_get_property_reply_t, QScopedPointerPodDeleter> reply(xcb_get_property_reply(c, cookie, nullptr));
     QVERIFY(!reply.isNull());
     QCOMPARE(reply->type, atom);
@@ -324,10 +306,9 @@ void KWindowEffectsTest::testBlur()
 {
     QFETCH(QRegion, blur);
 
-    KWindowEffects::enableBlurBehind(m_window->winId(), true, blur);
+    KWindowEffects::enableBlurBehind(m_window.data(), true, blur);
     xcb_connection_t *c = QX11Info::connection();
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(),
-                                       m_blur, XCB_ATOM_CARDINAL, 0, 100);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(), m_blur, XCB_ATOM_CARDINAL, 0, 100);
     QScopedPointer<xcb_get_property_reply_t, QScopedPointerPodDeleter> reply(xcb_get_property_reply(c, cookie, nullptr));
     QVERIFY(!reply.isNull());
     QCOMPARE(reply->type, xcb_atom_t(XCB_ATOM_CARDINAL));
@@ -335,7 +316,7 @@ void KWindowEffectsTest::testBlur()
     QCOMPARE(reply->value_len, uint32_t(blur.rectCount() * 4));
     uint32_t *data = static_cast<uint32_t *>(xcb_get_property_value(reply.data()));
     int dataOffset = 0;
-    for (const QRect& rect : blur) {
+    for (const QRect &rect : blur) {
         QCOMPARE(data[dataOffset++], uint32_t(rect.x()));
         QCOMPARE(data[dataOffset++], uint32_t(rect.y()));
         QCOMPARE(data[dataOffset++], uint32_t(rect.width()));
@@ -345,30 +326,29 @@ void KWindowEffectsTest::testBlur()
 
 void KWindowEffectsTest::testBlurDisable()
 {
-    KWindowEffects::enableBlurBehind(m_window->winId(), false);
+    KWindowEffects::enableBlurBehind(m_window.data(), false);
     performAtomIsRemoveTest(m_window->winId(), m_blur);
 
-    KWindowEffects::enableBlurBehind(m_window->winId(), true);
-    //verify that it got added
+    KWindowEffects::enableBlurBehind(m_window.data(), true);
+    // verify that it got added
     xcb_connection_t *c = QX11Info::connection();
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(),
-                                       m_blur, XCB_ATOM_CARDINAL, 0, 100);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(), m_blur, XCB_ATOM_CARDINAL, 0, 100);
     QScopedPointer<xcb_get_property_reply_t, QScopedPointerPodDeleter> reply(xcb_get_property_reply(c, cookie, nullptr));
     QVERIFY(!reply.isNull());
     QCOMPARE(reply->type, xcb_atom_t(XCB_ATOM_CARDINAL));
 
     // and disable
-    KWindowEffects::enableBlurBehind(m_window->winId(), false);
+    KWindowEffects::enableBlurBehind(m_window.data(), false);
     performAtomIsRemoveTest(m_window->winId(), m_blur);
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 67)
 void KWindowEffectsTest::testMarkAsDashboard()
 {
     const QByteArray className = QByteArrayLiteral("dashboard");
     // should not yet be set
     xcb_connection_t *c = QX11Info::connection();
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(),
-                                       XCB_ATOM_WM_CLASS, XCB_ATOM_STRING, 0, 100);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(c, false, m_window->winId(), XCB_ATOM_WM_CLASS, XCB_ATOM_STRING, 0, 100);
     QScopedPointer<xcb_get_property_reply_t, QScopedPointerPodDeleter> reply(xcb_get_property_reply(c, cookie, nullptr));
     QVERIFY(!reply.isNull());
     QCOMPARE(reply->type, xcb_atom_t(XCB_ATOM_STRING));
@@ -378,8 +358,7 @@ void KWindowEffectsTest::testMarkAsDashboard()
 
     // now mark as dashboard
     KWindowEffects::markAsDashboard(m_window->winId());
-    cookie = xcb_get_property_unchecked(c, false, m_window->winId(),
-                                        XCB_ATOM_WM_CLASS, XCB_ATOM_STRING, 0, 100);
+    cookie = xcb_get_property_unchecked(c, false, m_window->winId(), XCB_ATOM_WM_CLASS, XCB_ATOM_STRING, 0, 100);
     reply.reset(xcb_get_property_reply(c, cookie, nullptr));
     QVERIFY(!reply.isNull());
     QCOMPARE(reply->type, xcb_atom_t(XCB_ATOM_STRING));
@@ -390,6 +369,7 @@ void KWindowEffectsTest::testMarkAsDashboard()
     data = data + 10;
     QCOMPARE(QByteArray(data), className);
 }
+#endif
 
 void KWindowEffectsTest::testEffectAvailable_data()
 {
@@ -397,11 +377,15 @@ void KWindowEffectsTest::testEffectAvailable_data()
     QTest::addColumn<QByteArray>("propertyName");
 
     QTest::newRow("slide") << KWindowEffects::Slide << QByteArrayLiteral("_KDE_SLIDE");
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 82)
     QTest::newRow("PresentWindows") << KWindowEffects::PresentWindows << QByteArrayLiteral("_KDE_PRESENT_WINDOWS_DESKTOP");
     QTest::newRow("PresentWindowsGroup") << KWindowEffects::PresentWindowsGroup << QByteArrayLiteral("_KDE_PRESENT_WINDOWS_GROUP");
     QTest::newRow("HighlightWindows") << KWindowEffects::HighlightWindows << QByteArrayLiteral("_KDE_WINDOW_HIGHLIGHT");
+#endif
     QTest::newRow("BlurBehind") << KWindowEffects::BlurBehind << QByteArrayLiteral("_KDE_NET_WM_BLUR_BEHIND_REGION");
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 67)
     QTest::newRow("Dashboard") << KWindowEffects::Dashboard << QByteArrayLiteral("_WM_EFFECT_KDE_DASHBOARD");
+#endif
     QTest::newRow("BackgroundContrast") << KWindowEffects::BackgroundContrast << QByteArrayLiteral("_KDE_NET_WM_BACKGROUND_CONTRAST_REGION");
 }
 
