@@ -1,22 +1,9 @@
 /*
- *   Copyright 2014 Martin Gräßlin <mgraesslin@kde.org>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Lesser General Public
- *   License as published by the Free Software Foundation; either
- *   version 2.1 of the License, or (at your option) version 3, or any
- *   later version accepted by the membership of KDE e.V. (or its
- *   successor approved by the membership of KDE e.V.), which shall
- *   act as a proxy defined in Section 6 of version 3 of the license.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public
- *   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
+
 #include "kwindowinfo.h"
 #include "kwindowinfo_p.h"
 #include "kwindowsystem.h"
@@ -27,7 +14,6 @@
 #include "kwindowinfo_dummy_p.h"
 
 #include <QRect>
-#include <QGuiApplication>
 
 // private
 KWindowInfoPrivate *KWindowInfoPrivate::create(WId window, NET::Properties properties, NET::Properties2 properties2)
@@ -38,10 +24,16 @@ KWindowInfoPrivate *KWindowInfoPrivate::create(WId window, NET::Properties prope
 KWindowInfoPrivateDesktopFileNameExtension::KWindowInfoPrivateDesktopFileNameExtension() = default;
 KWindowInfoPrivateDesktopFileNameExtension::~KWindowInfoPrivateDesktopFileNameExtension() = default;
 
+KWindowInfoPrivateGtkApplicationIdExtension::KWindowInfoPrivateGtkApplicationIdExtension() = default;
+KWindowInfoPrivateGtkApplicationIdExtension::~KWindowInfoPrivateGtkApplicationIdExtension() = default;
+
 KWindowInfoPrivatePidExtension::KWindowInfoPrivatePidExtension() = default;
 KWindowInfoPrivatePidExtension::~KWindowInfoPrivatePidExtension() = default;
 
-class KWindowInfoPrivate::Private
+KWindowInfoPrivateAppMenuExtension::KWindowInfoPrivateAppMenuExtension() = default;
+KWindowInfoPrivateAppMenuExtension::~KWindowInfoPrivateAppMenuExtension() = default;
+
+class Q_DECL_HIDDEN KWindowInfoPrivate::Private
 {
 public:
     Private(WId window, NET::Properties properties, NET::Properties2 properties2);
@@ -49,7 +41,9 @@ public:
     NET::Properties properties;
     NET::Properties2 properties2;
     KWindowInfoPrivateDesktopFileNameExtension *desktopFileNameExtension;
+    KWindowInfoPrivateGtkApplicationIdExtension *gtkApplicationIdExtension;
     KWindowInfoPrivatePidExtension *pidExtension;
+    KWindowInfoPrivateAppMenuExtension *appMenuExtension;
 };
 
 KWindowInfoPrivate::Private::Private(WId window, NET::Properties properties, NET::Properties2 properties2)
@@ -57,7 +51,9 @@ KWindowInfoPrivate::Private::Private(WId window, NET::Properties properties, NET
     , properties(properties)
     , properties2(properties2)
     , desktopFileNameExtension(nullptr)
+    , gtkApplicationIdExtension(nullptr)
     , pidExtension(nullptr)
+    , appMenuExtension(nullptr)
 {
 }
 
@@ -85,6 +81,16 @@ void KWindowInfoPrivate::installDesktopFileNameExtension(KWindowInfoPrivateDeskt
     d->desktopFileNameExtension = extension;
 }
 
+KWindowInfoPrivateGtkApplicationIdExtension *KWindowInfoPrivate::gtkApplicationIdExtension() const
+{
+    return d->gtkApplicationIdExtension;
+}
+
+void KWindowInfoPrivate::installGtkApplicationIdExtension(KWindowInfoPrivateGtkApplicationIdExtension *extension)
+{
+    d->gtkApplicationIdExtension = extension;
+}
+
 KWindowInfoPrivatePidExtension *KWindowInfoPrivate::pidExtension() const
 {
     return d->pidExtension;
@@ -95,6 +101,16 @@ void KWindowInfoPrivate::installPidExtension(KWindowInfoPrivatePidExtension *ext
     d->pidExtension = extension;
 }
 
+KWindowInfoPrivateAppMenuExtension *KWindowInfoPrivate::appMenuExtension() const
+{
+    return d->appMenuExtension;
+}
+
+void KWindowInfoPrivate::installAppMenuExtension(KWindowInfoPrivateAppMenuExtension *extension)
+{
+    d->appMenuExtension = extension;
+}
+
 KWindowInfoPrivateDummy::KWindowInfoPrivateDummy(WId window, NET::Properties properties, NET::Properties2 properties2)
     : KWindowInfoPrivate(window, properties, properties2)
 {
@@ -256,8 +272,10 @@ KWindowInfo &KWindowInfo::operator=(const KWindowInfo &other)
     return *this;
 }
 
+// clang-format off
+
 #define DELEGATE(name, args) \
-    return d->name( args );
+    return d->name(args);
 
 bool KWindowInfo::valid(bool withdrawn_is_valid) const
 {
@@ -407,6 +425,30 @@ QByteArray KWindowInfo::desktopFileName() const
     return QByteArray();
 }
 
+QByteArray KWindowInfo::gtkApplicationId() const
+{
+    if (auto extension = d->gtkApplicationIdExtension()) {
+        return extension->gtkApplicationId();
+    }
+    return QByteArray();
+}
+
+QByteArray KWindowInfo::applicationMenuServiceName() const
+{
+    if (auto extension = d->appMenuExtension()) {
+        return extension->applicationMenuServiceName();
+    }
+    return QByteArray();
+}
+
+QByteArray KWindowInfo::applicationMenuObjectPath() const
+{
+    if (auto extension = d->appMenuExtension()) {
+        return extension->applicationMenuObjectPath();
+    }
+    return QByteArray();
+}
+
 int KWindowInfo::pid() const
 {
     if (auto extension = d->pidExtension()) {
